@@ -38,7 +38,7 @@ class generic_kv:
             if field_type == str:
                 return "String"
             elif field_type == int:
-                return "Integer"
+                return "Number"
             elif field_type == float:
                 return "Float"
             elif field_type == bool:
@@ -64,7 +64,7 @@ class generic_kv:
             "credentials": [cls.username, cls.password]
         })
 
-        return cls._run_query(query)
+        return await cls._run_query(query)
 
     @classmethod
     async def remove_enforced_schema(cls, schema):
